GenericDataBlockHeader

Struct GenericDataBlockHeader 

pub struct GenericDataBlockHeader {
    pub data_block_id: DataBlockId,
    pub reserved: u32,
    pub number_of_data_moment_gates: u16,
    pub data_moment_range: u16,
    pub data_moment_range_sample_interval: u16,
    pub tover: u16,
    pub snr_threshold: u16,
    pub control_flags: u8,
    pub data_word_size: u8,
    pub scale: f32,
    pub offset: f32,
}
A generic data moment block’s decoded header.

Fields

data_block_id: DataBlockId

Data block identifier.

reserved: u32

Reserved.

number_of_data_moment_gates: u16

Number of data moment gates for current radial, from 0 to 1840.

data_moment_range: u16

Range to center of first range gate in 0.000-scaled kilometers.

data_moment_range_sample_interval: u16

Size of data moment sample interval in 0.000-scaled kilometers from 0.25 to 4.0.

tover: u16

Threshold parameter specifying the minimum difference in echo power between two resolution gates in dB for them to not be labeled as “overlayed”.

snr_threshold: u16

Signal-to-noise ratio threshold for valid data from -12 to 20 dB.

control_flags: u8

Flags indicating special control features.

Flags: 0 = None 1 = Recombined azimuthal radials 2 = Recombined range gates 3 = Recombined radials and range gates to legacy resolution

data_word_size: u8

Number of bits (8 or 16) used for storing data for each data moment gate.

scale: f32

Scale factor for converting data moments to floating-point representation.

offset: f32

Offset value for converting data moments to floating-point representation.

Implementations

Source

impl GenericDataBlockHeader

pub fn data_moment_range(&self) -> Length

Range to center of first range gate.

pub fn data_moment_range_sample_interval(&self) -> Length

Size of data moment sample interval.

pub fn control_flags(&self) -> ControlFlags

Flags indicating special control features.

pub fn moment_size(&self) -> Information

Size of the data moment block in bytes.