Module volume_coverage_pattern

Module volume_coverage_pattern 

Message type 5 “Volume Coverage Pattern” provides details about the volume coverage pattern being used. The RDA sends the Volume Coverage Pattern message upon wideband connection and at the beginning of each volume scan. The volume coverage pattern message includes a header which describes how the volume is being collected as well as a block for each elevation cut detailing the radar settings being used for that cut.

Structs

ElevationDataBlock
A data block for a single elevation cut.
Header
The volume coverage pattern header block
Message
The digital radar data message includes base radar data from a single radial for various products.

Enums

ChannelConfiguration
Possible values for channel configuration
PatternType
Possible values for the VCP pattern type
PulseWidth
Possible values for pulse width
WaveformType
Possible values for waveform type

Functions

decode_volume_coverage_pattern
Decodes a volume coverage pattern message type 5 from the provided reader.