Header

Struct Header 

pub struct Header {
    pub message_size: u16,
    pub pattern_type: u16,
    pub pattern_number: u16,
    pub number_of_elevation_cuts: u16,
    pub version: u8,
    pub clutter_map_group_number: u8,
    pub doppler_velocity_resolution: u8,
    pub pulse_width: u8,
    pub reserved_1: u32,
    pub vcp_sequencing: u16,
    pub vcp_supplemental_data: u16,
    pub reserved_2: u16,
}
The volume coverage pattern header block

Fields

message_size: u16

Total message size in halfwords, including the header and all elevation blocks

pattern_type: u16

Pattern type is always 2

pattern_number: u16

Volume Coverage Pattern Number

number_of_elevation_cuts: u16

Number of elevation cuts in the complete volume scan

version: u8

Volume Coverage Pattern Version Number

clutter_map_group_number: u8

Clutter map groups are not currently implemented

doppler_velocity_resolution: u8

Doppler velocity resolution. 2 -> 0.5 4 -> 1.0

pulse_width: u8

Pulse width values. 2 -> Short 4 -> Long

reserved_1: u32

Reserved

vcp_sequencing: u16

VCP sequencing values. Bits 0-4: Number of Elevations Bits 5-6: Maximum SAILS Cuts Bit 13: Sequence Active Bit 14: Truncated VCP

vcp_supplemental_data: u16

VCP supplemental data. Bit 0: SAILS VCP Bits 1-3: Number SAILS Cuts Bit 4: MRLE VCP Bits 5-7: Number MRLE Cuts Bits 8-10: Spare Bit 11: MPDA VCP Bit 12: BASE TILT VCP Bits 13-15: Number of BASE TILTS

reserved_2: u16

Reserved

Implementations

Source

impl Header

pub fn pattern_type(&self) -> PatternType

The pattern type of the volume coverage pattern

pub fn doppler_velocity_resolution(&self) -> Option<Velocity>

The doppler velocity resolution of this coverage pattern

pub fn doppler_velocity_resolution_meters_per_second(&self) -> Option<f64>

The doppler velocity resolution of this coverage pattern in m/s

pub fn pulse_width(&self) -> PulseWidth

The pulse width for this VCP

pub fn vcp_sequencing_number_of_elevations(&self) -> u8

The number of elevations in the VCP

pub fn vcp_sequencing_maximum_sails_cuts(&self) -> u8

The maximum number of SAILS cuts allowed in this VCP

pub fn vcp_sequencing_sequence_active(&self) -> bool

Whether this VCP is a part of an active VCP sequence

pub fn vcp_sequencing_truncated_vcp(&self) -> bool

Whether this VCP is truncated

pub fn vcp_supplemental_data_sails_vcp(&self) -> bool

Whether this VCP uses SAILS cuts

pub fn vcp_supplemental_data_number_sails_cuts(&self) -> u8

The number of SAILS cuts used by this VCP

pub fn vcp_supplemental_data_mrle_vcp(&self) -> bool

Whether this VCP uses MRLE cuts

pub fn vcp_supplemental_data_number_mrle_cuts(&self) -> u8

The number of MRLE cuts used by this VCP

pub fn vcp_supplemental_data_mpda_vcp(&self) -> bool

Whether this VCP is a Multi-PRF Dealiasing Algorithm (MPDA) VCP

pub fn vcp_supplemental_data_base_tilt_vcp(&self) -> bool

Whether this VCP contains BASE TILTS

pub fn vcp_supplemental_data_base_tilts(&self) -> u8

The number of BASE TILTS in this VCP