pub enum MessageContents {
RDAStatusData(Box<Message>),
DigitalRadarData(Box<Message>),
ClutterFilterMap(Box<Message>),
VolumeCoveragePattern(Box<Message>),
Other,
}Expand description
A decoded NEXRAD Level II message’s contents.
Variants
RDAStatusData(Box<Message>)
Message type 2 “RDA Status Data” contains information about the current RDA state, system control, operating status, scanning strategy, performance parameters like transmitter power and calibration, and system alarms
DigitalRadarData(Box<Message>)
Message type 31 “Digital Radar Data” consists of base data information such as reflectivity, mean radial velocity, spectrum width, differential reflectivity, differential phase, correlation coefficient, azimuth angle, elevation angle, cut type, scanning strategy, and calibration parameters.
ClutterFilterMap(Box<Message>)
Message type 15 “Clutter Filter Map” contains information about clutter filter maps that are used to filter clutter from radar products
VolumeCoveragePattern(Box<Message>)
Message type 5 “Volume Coverage Pattern” provides details about the volume coverage pattern being used, including detailed settings for each elevation.
Other