Message type 5 “Volume Coverage Pattern” provides details about the volume coverage pattern being used. The RDA sends the Volume Coverage Pattern message upon wideband connection and at the beginning of each volume scan. The volume coverage pattern message includes a header which describes how the volume is being collected as well as a block for each elevation cut detailing the radar settings being used for that cut.
Structs
- Elevation
Data Block - A data block for a single elevation cut.
- Header
- The volume coverage pattern header block
- Message
- The digital radar data message includes base radar data from a single radial for various products.
Enums
- Channel
Configuration - Possible values for channel configuration
- Pattern
Type - Possible values for the VCP pattern type
- Pulse
Width - Possible values for pulse width
- Waveform
Type - Possible values for waveform type
Functions
- decode_
volume_ coverage_ pattern - Decodes a volume coverage pattern message type 5 from the provided reader.