pub struct ElevationDataBlock {Show 25 fields
pub elevation_angle: u16,
pub channel_configuration: u8,
pub waveform_type: u8,
pub super_resolution_control: u8,
pub surveillance_prf_number: u8,
pub surveillance_prf_pulse_count_radial: u16,
pub azimuth_rate: u16,
pub reflectivity_threshold: i16,
pub velocity_threshold: i16,
pub spectrum_width_threshold: i16,
pub differential_reflectivity_threshold: i16,
pub differential_phase_threshold: i16,
pub correlation_coefficient_threshold: i16,
pub sector_1_edge_angle: u16,
pub sector_1_doppler_prf_number: u16,
pub sector_1_doppler_prf_pulse_count_radial: u16,
pub supplemental_data: u16,
pub sector_2_edge_angle: u16,
pub sector_2_doppler_prf_number: u16,
pub sector_2_doppler_prf_pulse_count_radial: u16,
pub ebc_angle: u16,
pub sector_3_edge_angle: u16,
pub sector_3_doppler_prf_number: u16,
pub sector_3_doppler_prf_pulse_count_radial: u16,
pub reserved: u16,
}Expand description
A data block for a single elevation cut.
Fields
elevation_angle: u16The elevation angle for this cut
channel_configuration: u8The channel configuration for this cut 0 => Constant Phase 1 => Random Phase 2 => SZ2 Phase
waveform_type: u8The waveform type for this cut 1 => Contiguous Surveillance 2 => Contiguous Doppler w/ Ambiguity Resolution 3 => Contiguous Doppler w/o Ambiguity Resolution 4 => Batch 5 => Staggered Pulse Pair
super_resolution_control: u8Super resolution control values for this cut Bit 0: 0.5 degree azimuth Bit 1: 1/4 km reflectivity Bit 2: Doppler to 300 km Bit 3: Dual polarization to 300 km
surveillance_prf_number: u8The pulse repetition frequency number for surveillance cuts
surveillance_prf_pulse_count_radial: u16The pulse count per radial for surveillance cuts
azimuth_rate: u16The azimuth rate of the cut
reflectivity_threshold: i16Signal to noise ratio (SNR) threshold for reflectivity
velocity_threshold: i16Signal to noise ratio (SNR) threshold for velocity
spectrum_width_threshold: i16Signal to noise ratio (SNR) threshold for spectrum width
differential_reflectivity_threshold: i16Signal to noise ratio (SNR) threshold for differential reflectivity
differential_phase_threshold: i16Signal to noise ratio (SNR) threshold for differential phase
correlation_coefficient_threshold: i16Signal to noise ratio (SNR) threshold for correlation coefficitn
sector_1_edge_angle: u16Sector 1 Azimuth Clockwise Edge Angle (denotes start angle)
sector_1_doppler_prf_number: u16Sector 1 Doppler PRF Number
sector_1_doppler_prf_pulse_count_radial: u16Sector 1 Doppler Pulse Count/Radial
supplemental_data: u16Supplemental Data Bit 0: SAILS Cut Bits 1-3: SAILS Sequence Number Bit 4: MRLE Cut Bits 5-7: MRLE Sequence Number Bit 8: Spare Bit 9: MPDA Cut Bit 10: BASE TILT Cut
sector_2_edge_angle: u16Sector 2 Azimuth Clockwise Edge Angle (denotes start angle)
sector_2_doppler_prf_number: u16Sector 2 Doppler PRF Number
sector_2_doppler_prf_pulse_count_radial: u16Sector 2 Doppler Pulse Count/Radial
ebc_angle: u16The correction added to the elevation angle for this cut
sector_3_edge_angle: u16Sector 3 Azimuth Clockwise Edge Angle (denotes start angle)
sector_3_doppler_prf_number: u16Sector 3 Doppler PRF Number
sector_3_doppler_prf_pulse_count_radial: u16Sector 3 Doppler Pulse Count/Radial
reserved: u16Reserved
Implementations
Sourceimpl ElevationDataBlock
impl ElevationDataBlock
Sourcepub fn elevation_angle(&self) -> Angle
pub fn elevation_angle(&self) -> Angle
The elevation angle for this cut
Sourcepub fn elevation_angle_degrees(&self) -> f64
pub fn elevation_angle_degrees(&self) -> f64
The elevation angle for this cut, in degrees
Sourcepub fn channel_configuration(&self) -> ChannelConfiguration
pub fn channel_configuration(&self) -> ChannelConfiguration
The channel configuration for this cut
Sourcepub fn waveform_type(&self) -> WaveformType
pub fn waveform_type(&self) -> WaveformType
The waveform type for this cut
Sourcepub fn super_resolution_control_half_degree_azimuth(&self) -> bool
pub fn super_resolution_control_half_degree_azimuth(&self) -> bool
Whether this cut uses super resolution 0.5 degree azimuth
Sourcepub fn super_resolution_control_quarter_km_reflectivity(&self) -> bool
pub fn super_resolution_control_quarter_km_reflectivity(&self) -> bool
Whether this cut uses super resolution 0.25 km reflectivity
Sourcepub fn super_resolution_control_doppler_to_300km(&self) -> bool
pub fn super_resolution_control_doppler_to_300km(&self) -> bool
Whether this cut uses super resolution doppler to 300 km
Sourcepub fn super_resolution_control_dual_polarization_to_300km(&self) -> bool
pub fn super_resolution_control_dual_polarization_to_300km(&self) -> bool
Whether this cut uses super resolution dual polarization to 300km
Sourcepub fn azimuth_rate(&self) -> AngularVelocity
pub fn azimuth_rate(&self) -> AngularVelocity
The azimuth rate used for this cut
Sourcepub fn azimuth_rate_degrees_per_second(&self) -> f64
pub fn azimuth_rate_degrees_per_second(&self) -> f64
The azimuth rate used for this cut, in degrees per second
Sourcepub fn reflectivity_threshold(&self) -> f64
pub fn reflectivity_threshold(&self) -> f64
The reflectivity threshold for this cut
Sourcepub fn velocity_threshold(&self) -> f64
pub fn velocity_threshold(&self) -> f64
The velocity threshold for this cut
Sourcepub fn spectrum_width_threshold(&self) -> f64
pub fn spectrum_width_threshold(&self) -> f64
The spectrum width threshold for this cut
Sourcepub fn differential_reflectivity_threshold(&self) -> f64
pub fn differential_reflectivity_threshold(&self) -> f64
The differential reflectivity threshold for this cut
Sourcepub fn differential_phase_threshold(&self) -> f64
pub fn differential_phase_threshold(&self) -> f64
The differential phase threshold for this cut
Sourcepub fn correlation_coefficient_threshold(&self) -> f64
pub fn correlation_coefficient_threshold(&self) -> f64
The correlation coefficient threshold for this cut
Sourcepub fn sector_1_edge_angle(&self) -> Angle
pub fn sector_1_edge_angle(&self) -> Angle
Sector 1 Azimuth Clockwise Edge Angle (denotes start angle)
Sourcepub fn sector_1_edge_angle_degrees(&self) -> f64
pub fn sector_1_edge_angle_degrees(&self) -> f64
Sector 1 Azimuth Clockwise Edge Angle (denotes start angle), in degrees
Sourcepub fn sector_2_edge_angle(&self) -> Angle
pub fn sector_2_edge_angle(&self) -> Angle
Sector 2 Azimuth Clockwise Edge Angle (denotes start angle)
Sourcepub fn sector_2_edge_angle_degrees(&self) -> f64
pub fn sector_2_edge_angle_degrees(&self) -> f64
Sector 2 Azimuth Clockwise Edge Angle (denotes start angle), in degrees
Sourcepub fn sector_3_edge_angle(&self) -> Angle
pub fn sector_3_edge_angle(&self) -> Angle
Sector 3 Azimuth Clockwise Edge Angle (denotes start angle)
Sourcepub fn sector_3_edge_angle_degrees(&self) -> f64
pub fn sector_3_edge_angle_degrees(&self) -> f64
Sector 3 Azimuth Clockwise Edge Angle (denotes start angle), in degrees
Sourcepub fn ebc_angle_degrees(&self) -> f64
pub fn ebc_angle_degrees(&self) -> f64
The correction added to the elevation angle for this cut, in degrees
Sourcepub fn supplemental_data_sails_cut(&self) -> bool
pub fn supplemental_data_sails_cut(&self) -> bool
Whether this cut is a SAILS cut
Sourcepub fn supplemental_data_sails_sequence_number(&self) -> u8
pub fn supplemental_data_sails_sequence_number(&self) -> u8
The SAILS sequence number of this cut
Sourcepub fn supplemental_data_mrle_cut(&self) -> bool
pub fn supplemental_data_mrle_cut(&self) -> bool
Whether this cut is an MRLE cut
Sourcepub fn supplemental_data_mrle_sequence_number(&self) -> u8
pub fn supplemental_data_mrle_sequence_number(&self) -> u8
The MRLE sequence number of this cut
Sourcepub fn supplemental_data_mpda_cut(&self) -> bool
pub fn supplemental_data_mpda_cut(&self) -> bool
Whether this cut is an MPDA cut
Sourcepub fn supplemental_data_base_tilt_cut(&self) -> bool
pub fn supplemental_data_base_tilt_cut(&self) -> bool
Whether this cut is a BASE TILT cut